@@ -31,6 +31,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
+#include <X11/keysym.h>
 #include <stdio.h>
 #include <time.h>
 
@@ -96,6 +97,7 @@ int ImgPause(theDsp, pause)
   theRoot = RootWindow(theDsp, DefaultScreen(theDsp));
   XGrabKeyboard(theDsp, theRoot,
                 False, GrabModeAsync, GrabModeAsync, CurrentTime);
+
   time(&t1); t2 = t1;
   while(1) {
     if ((t2 - t1) > pause) {
@@ -103,12 +105,15 @@ int ImgPause(theDsp, pause)
       return -1;
     }
     if (0 != XCheckTypedEvent(theDsp, KeyPress, &event)) {
-      XUngrabKeyboard(theDsp, CurrentTime);
-      return 0; 
+      if( XKeycodeToKeysym(theDsp, event.xkey.keycode, 0) == XK_space ){
+	XUngrabKeyboard(theDsp, CurrentTime);
+        return 0; 
+      }
     }
     time(&t2);
   }
 }
+
 /***********************************************************************
  *                                                                     *
  * Name: ImgFreeImage                                Date:    07.01.93 *
@@ -446,7 +451,7 @@ void ImgGetRectangle(display, window, xorigin, yorigin, width, height)
   /*   U N G R A B E   P O I N T E R   */
 
   XUngrabPointer(theDsp, CurrentTime);
-  XFlush(theDsp); 
+  XSync(theDsp, False); 
 
   /*   F I N D   W I N D O W   F O R   P I C K   P A L E T T E  */
 
@@ -548,7 +553,10 @@ int ImgGetWindowById(display, window, xorigin, yorigin, width, height)
 
   if (!XGetGeometry(theDsp, window, &rW, &x, &y, &ww, &hh, &border, &depth))
     return (-1);
-
+/*
+  XMapRaised(theDsp,window);
+  XSync(theDsp, False);
+*/  
   w = ww; h = hh;
   XTranslateCoordinates(theDsp, window, theRoot, 0, 0, &x, &y, &rW);
   if (x < 0) { w += x; x = 0; }
@@ -607,5 +615,5 @@ void ImgFinalFlash(display, x, y, w, h)
   XSetSubwindowMode(theDsp, theGC, ClipByChildren);
   XSetPlaneMask(theDsp, theGC, AllPlanes);
   XUngrabKeyboard(theDsp, CurrentTime);
-  XFlush(theDsp);
+  XSync(theDsp, False);
 }
