@@ -468,7 +468,7 @@ long PS_LZWencode(iwhat, Width, Height, Ncol, R, G, B, ScLine, get_scline, pb)
     "  /Ymax rows def /Xmax colomns def /Ymin 0 def /Xmin 0 def",
     "}{",
     "  /IfRotate colomns rows gt {true} {false} ifelse def",
-    "  /MarginX 5 mm def /MarginY 5 mm def",
+    "  /MarginX 8 mm def /MarginY 18 mm def",
     "  0 0 moveto clippath pathbbox",
     "  /Ymax exch def /Xmax exch def /Ymin exch def /Xmin exch def",
     "} ifelse",
@@ -555,8 +555,8 @@ long PS_LZWencode(iwhat, Width, Height, Ncol, R, G, B, ScLine, get_scline, pb)
     "  /FactorX DelX SizeX div def /FactorY DelY SizeY div def",
     "  /Factor FactorX FactorY le {FactorX} {FactorY} ifelse def",
     "  /ScaleX SizeX Factor mul def /ScaleY SizeY Factor mul def",
-    "  DelX ScaleX sub 2 div MarginX add",
-    "  DelY ScaleY sub 2 div MarginY add translate",
+    "  Xmin DelX ScaleX sub 2 div MarginX add add",
+    "  Ymin DelY ScaleY sub 2 div MarginY add add translate",
     "  IfRotate {ScaleY ScaleX} {ScaleX ScaleY} ifelse scale",
     "  /Palette currentfile 768 string readhexstring pop def",
     "  currentfile InLine readline pop pop",
